<?php
/*
Plugin Name: faspaycc Gateway
Plugin URI: http://faspay.co.id/
Description: faspaycc Payment Gateway.
Version: 1.0
Author: Umar Sidik@ faspaycc.

License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html   
*/

add_action('plugins_loaded', 'faspaycc_gateway_init', 0);

function faspaycc_gateway_init() {

	if ( !class_exists( 'WC_Payment_Gateway' ) ) return;

	load_plugin_textdomain('wc-gateway-name', false, dirname( plugin_basename( __FILE__ ) ) . '/languages');

	/**
 	 * Gateway class
 	 */
	class WC_Gateway_faspaycc extends WC_Payment_Gateway {
       public function __construct(){

        $this->id			= 'faspaycc';

        $this->has_fields 	= false;

		// Load the form fields
        $this->init_form_fields();

		// Load the settings.
        $this->init_settings();

        // Get setting values
        $this->enabled 		= $this->settings['enabled'];
        $this->title 		= $this->settings['title'];
        $this->description	= $this->settings['description'];
        $this->password		= $this->settings['password'];

        if ( version_compare( WOOCOMMERCE_VERSION, '2.0.0', '>=' ) ) {
           add_action( 'woocommerce_update_options_payment_gateways_' . $this->id,
              array( &$this, 'process_admin_options' ) 
              );
           add_action('woocommerce_receipt_'.$this->id, array(&$this, 'receipt_page'));
           add_action('admin_notices_'.$this->id, array(&$this,'faspaycc_ssl_check'));

           add_action('woocommerce_thankyou_'.$this->id, array(&$this, 'thankyou_page'));
       } else {
           add_action( 'woocommerce_update_options_payment_gateways', 
              array( &$this, 'process_admin_options' ) 
              );
           add_action('woocommerce_receipt_faspaycc', array(&$this, 'receipt_page'));
           add_action('admin_notices', array(&$this,'faspaycc_ssl_check'));

           add_action('woocommerce_thankyou_faspaycc', array(&$this, 'thankyou_page'));

       }
   }

    public function thankyou_page(){}


		/**
	     * Initialize Gateway Settings Form Fields
	     */
    public function init_form_fields() {

      $this->form_fields = array(
        'enabled' => array(
            'title' => __( 'Enable/Disable', 'woothemes' ), 
            'label' => __( 'Enable faspaycc', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ), 
        'title' => array(
            'title' => __( 'Title', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'This controls the title which the user sees during checkout.', 'woothemes' ), 
            'default' => __( 'Pembayaran Kartu Kredit faspay', 'woothemes' )
            ),
        'description' => array(
            'title' => __( 'Description', 'woothemes' ), 
            'type' => 'textarea', 
            'description' => __( 'This controls the description which the user sees during checkout.', 'woothemes' ), 
            'default' => 'Sistem pembayaran Kartu Kredit menggunakan faspay.'
            ),  			
        'merchant_name' => array(
            'title' => __( 'Merchant Name', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'Please field merchant name.', 'woothemes' ), 
            ),
		'server' => array(
            'title' => __( 'Server', 'woothemes' ), 
            'type' => 'select',
            'options'  => array(
               'development' => __( 'Development', 'woothemes' ),

               'production'   => __( 'Production', 'woothemes' )
               ), 
            'description' => __( 'Please field server.', 'woothemes' ), 
            ),
        'parameter_all' => array(
            'title' => __( 'Configuration for Visa/Master :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_all' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Visa/Master', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_all' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_all' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_all' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_all' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),		
        'parameter_500' => array(
            'title' => __( 'Configuration for Mandiri :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_500' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Mandiri Credit Card', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_500' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_500' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_500' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_500' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'parameter_500_3' => array(
            'title' => __( 'Configuration for mandiri Installment 3 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_500_3' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable mandiri Credit Card Installment 3 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_500_3' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_500_3' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_500_3' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_500_3' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),	
		'parameter_500_6' => array(
            'title' => __( 'Configuration for mandiri Installment 6 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_500_6' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable mandiri Credit Card Installment 6 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_500_6' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_500_6' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_500_6' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_500_6' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_500_12' => array(
            'title' => __( 'Configuration for mandiri Installment 12 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_500_12' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable mandiri Credit Card Installment 12 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_500_12' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_500_12' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_500_12' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_500_12' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_500_24' => array(
            'title' => __( 'Configuration for mandiri Installment 24 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_500_24' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable mandiri Credit Card Installment 24 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_500_24' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_500_24' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_500_24' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_500_24' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_501' => array(
            'title' => __( 'Configuration for BCA :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_501' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable BCA Credit Card', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_501' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_501' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_501' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_501' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'parameter_501_3' => array(
            'title' => __( 'Configuration for BCA Installment 3 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_501_3' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable BCA Credit Card Installment 3 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_501_3' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_501_3' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_501_3' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_501_3' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),	
		'parameter_501_6' => array(
            'title' => __( 'Configuration for BCA Installment 6 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_501_6' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable BCA Credit Card Installment 6 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_501_6' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_501_6' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_501_6' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_501_6' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_501_12' => array(
            'title' => __( 'Configuration for BCA Installment 12 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_501_12' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable BCA Credit Card Installment 12 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_501_12' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_501_12' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_501_12' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_501_12' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_501_24' => array(
            'title' => __( 'Configuration for BCA Installment 24 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_501_24' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable BCA Credit Card Installment 24 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_501_24' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_501_24' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_501_24' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_501_24' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_502' => array(
            'title' => __( 'Configuration for CIMB :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_502' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable CIMB Credit Card', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_502' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_502' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_502' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_502' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'parameter_502_3' => array(
            'title' => __( 'Configuration for CIMB Installment 3 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_502_3' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable CIMB Credit Card Installment 3 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_502_3' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_502_3' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_502_3' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_502_3' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),	
		'parameter_502_6' => array(
            'title' => __( 'Configuration for CIMB Installment 6 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_502_6' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable CIMB Credit Card Installment 6 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_502_6' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_502_6' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_502_6' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_502_6' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_502_12' => array(
            'title' => __( 'Configuration for CIMB Installment 12 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_502_12' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable CIMB Credit Card Installment 12 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_502_12' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_502_12' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_502_12' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_502_12' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_502_24' => array(
            'title' => __( 'Configuration for CIMB Installment 24 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_502_24' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable CIMB Credit Card Installment 24 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_502_24' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_502_24' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_502_24' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_502_24' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_503' => array(
            'title' => __( 'Configuration for Danamon :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_503' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Danamon Credit Card', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_503' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_503' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_503' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_503' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'parameter_503_3' => array(
            'title' => __( 'Configuration for Danamon Installment 3 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_503_3' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Danamon Credit Card Installment 3 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_503_3' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_503_3' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_503_3' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_503_3' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),	
		'parameter_503_6' => array(
            'title' => __( 'Configuration for Danamon Installment 6 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_503_6' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Danamon Credit Card Installment 6 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_503_6' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_503_6' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_503_6' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_503_6' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_503_12' => array(
            'title' => __( 'Configuration for Danamon Installment 12 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_503_12' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Danamon Credit Card Installment 12 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_503_12' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_503_12' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_503_12' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_503_12' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_503_24' => array(
            'title' => __( 'Configuration for Danamon Installment 24 Month :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_503_24' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Danamon Credit Card Installment 24 Month', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_503_24' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_503_24' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_503_24' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_503_24' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		'parameter_pro_1' => array(
            'title' => __( 'Configuration for Credit Card Promotion 1 :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_pro_1' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Credit Card Promotion 1', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_pro_1' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_pro_1' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_pro_1' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_pro_1' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'parameter_pro_2' => array(
            'title' => __( 'Configuration for Credit Card Promotion 2 :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_pro_2' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Credit Card Promotion 2', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_pro_2' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_pro_2' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_pro_2' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_pro_2' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),	
		'parameter_pro_3' => array(
            'title' => __( 'Configuration for Credit Card Promotion 3 :', 'woothemes' ), 
            'type' => 'hidden',  
            ),
		'status_pro_3' => array(
            'title' => __( 'Status', 'woothemes' ), 
            'label' => __( 'Enable Credit Card Promotion 3', 'woothemes' ), 
            'type' => 'checkbox', 
            'description' => '', 
            'default' => 'no'
            ),		
		'mid_pro_3' => array(
            'title' => __( 'MID', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pass_pro_3' => array(
            'title' => __( 'Pasword', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtind_pro_3' => array(
            'title' => __( 'Payment Indicator', 'woothemes' ), 
            'type' => 'text',  
            ),		
		'pymtcri_pro_3' => array(
            'title' => __( 'Payment Criteria', 'woothemes' ), 
            'type' => 'text',  
            ),
		);
    }

		/**
		 * Admin Panel Options 
		 * - Options for bits like 'title' and availability on a country-by-country basis
		 **/
    public function admin_options() {
        ?>
        <h3><?php _e('faspaycc','woothemes'); ?></h3>	    	
        <p>
        <?php _e( 'FaspayCC Gateway Systems', 'woothemes' ); ?>
        </p>
        <table class="form-table">
        <?php $this->generate_settings_html(); ?>
        </table>    	
        <p>
        <?php
    }

	    /**
		 * Payment fields for faspaycc
		 **/	
    public function generate_faspaycc_form( $order_id ) {
        global $woocommerce;

        $order = new WC_Order( $order_id );

        $item_loop = 0;

        if (sizeof($order->get_items())>0) : 
            foreach ($order->get_items() as $item) :
                if ($item['qty']) :

                $item_loop++;

                $faspaycc_args['item_name_'.$item_loop] = $item['name'];
                $faspaycc_args['quantity_'.$item_loop] = $item['qty'];
                $faspaycc_args['amount_'.$item_loop] = $item['line_total'];

                endif;
            endforeach; 
        endif;

		// Shipping Cost
        $item_loop++;
        $faspaycc_args['item_name_'.$item_loop] = __('Shipping cost', 'woothemes');
        $faspaycc_args['quantity_'.$item_loop] = '1';
        $faspaycc_args['amount_'.$item_loop] = number_format(floatval($order->order_shipping), 2);

        $faspaycc_args_array = array();

        foreach ($faspaycc_args as $key => $value) {
           $faspaycc_args_array[] = '<input type="hidden" name="'.$key.'" value="'.esc_attr( $value ).'" />';
       }

		// PrepareParameters
       $params = array(
         'action'   => 'payment',
         'product'  => 'Order : #'.$order_id.'',
					'price'    => ''.$order->order_total.'', // Total Amount
					'quantity' => 1,
					'comments' => 'Transaksi Pembelian', // Optional           
					'ureturn'  => add_query_arg('key', $order->order_key, add_query_arg('order', $order_id, get_permalink(get_option('woocommerce_thanks_page_id')))),
					'unotify'  => 'http://domain.com/notify.php',
					'ucancel'  => 'http://domain.com/cancel.php',
					'format'   => 'json' // Format: xml / json. Default: xml 
        );

		//CreateTables
       function divebook_create_table_dive(){

		//GetTheTableNameWithTheWPdatabasePrefix
            global $wpdb;
            $table_name = $wpdb->prefix . "faspaycc_order";
            
            global $divebook_db_table_dive_version;
            $installed_ver = get_option( "divebook_db_table_dive_version" );

    		//Check if the table already exists and if the table is up to date, if not create it
            if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name ||  $installed_ver != $divebook_db_table_dive_version ) {
                $sql = "CREATE TABLE " . $table_name . " (
                      trx_id bigint(10),
                      order_id varchar(30) NOT NULL,
                      date_trx datetime NOT NULL,
                      total_amount varchar(30) NOT NULL,
					  payment varchar(10) NOT NULL,
					  installment varchar(2),
                      approval_code varchar(30) NOT NULL,
                      status varchar(3) NOT NULL
                      );";

                require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
                dbDelta($sql);
                update_option( "divebook_db_table_dive_version", $divebook_db_table_dive_version );
            }
            //AddDatabaseTableVersionsToOptions
            add_option("divebook_db_table_dive_version", $divebook_db_table_dive_version);
        }
        		//ExecCreateTable	
        divebook_create_table_dive();

        global $wpdb;

        		//Choose Payment Gateways	
        echo "<ul class=customer_details><li>Please Choose Payment Channel :</li><p></p>";

        echo "<form action='' method=post>";
        		//SelectDataChoosePaymentGateway
        $sql = "SELECT ". $wpdb->prefix ."options.option_value FROM ". $wpdb->prefix ."options WHERE ". $wpdb->prefix ."options.option_name = 'woocommerce_faspaycc_settings'";
        $active_plugins_data ="";

        $paymentlist = $wpdb->get_results($sql, ARRAY_A);

        foreach ($paymentlist as $rows) {  
            $active_plugins_data .= $rows["option_value"];
        }

        $array = unserialize($active_plugins_data);
        $merchant_name				= $array["merchant_name"];
        $server						= $array["server"];

        $stat_all					= $array["status_all"];
        $stat_500                 	= $array["status_500"];
        $stat_500_3                 = $array["status_500_3"];
        $stat_500_6                 = $array["status_500_6"];
        $stat_500_12				= $array["status_500_12"];
        $stat_500_24				= $array["status_500_24"];
		$stat_501                 	= $array["status_501"];
        $stat_501_3                 = $array["status_501_3"];
        $stat_501_6                 = $array["status_501_6"];
        $stat_501_12				= $array["status_501_12"];
        $stat_501_24				= $array["status_501_24"];
		$stat_503                 	= $array["status_503"];
        $stat_503_3                 = $array["status_503_3"];
        $stat_503_6                 = $array["status_503_6"];
        $stat_503_12				= $array["status_503_12"];
        $stat_503_24				= $array["status_503_24"];
		$stat_502                 	= $array["status_502"];
        $stat_502_3                 = $array["status_502_3"];
        $stat_502_6                 = $array["status_502_6"];
        $stat_502_12				= $array["status_502_12"];
        $stat_502_24				= $array["status_502_24"];
		$stat_pro_1                 = $array["status_pro_1"];
        $stat_pro_2                 = $array["status_pro_2"];
        $stat_pro_3                 = $array["status_pro_3"];
        

        echo "<table width=100% border='0'>";

        if($stat_all == 'yes'){
            echo"<tr><td><input type=radio name=payment value=all id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_all.png' title='Pembayaran melalui Visa/Master Credit Card'></td>";
			echo"<td></td>";
        }
		if($stat_500 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=500 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_500.png' title='Pembayaran melalui Mandiri Credit Card'></td>";
			echo "<td><select name='option_500'>";
			echo "<option value='500'>Full Payment</option>";
			if ($stat_500_3 =='yes'){
				echo "<option value='500_3'>Installment 3 Months</option>";
			}
			if ($stat_500_6 =='yes'){
				echo "<option value='500_6'>Installment 6 Months</option>";
			}
			if ($stat_500_12 =='yes'){
				echo "<option value='500_12'>Installment 12 Months</option>";
			}
			if ($stat_500_24 =='yes'){
				echo "<option value='500_24'>Installment 24 Months</option>";
			}
			echo "</td>";
        }
        if($stat_501 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=501 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_501.png' title='Pembayaran melalui BCA Credit Card'></td>";
			echo "<td><select name='option_501'>";
			echo "<option value='501'>Full Payment</option>";
			if ($stat_501_3 =='yes'){
				echo "<option value='501_3'>Installment 3 Months</option>";
			}
			if ($stat_501_6 =='yes'){
				echo "<option value='501_6'>Installment 6 Months</option>";
			}
			if ($stat_501_12 =='yes'){
				echo "<option value='501_12'>Installment 12 Months</option>";
			}
			if ($stat_501_24 =='yes'){
				echo "<option value='501_24'>Installment 24 Months</option>";
			}
			echo "</td>";
        }
        if($stat_502 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=502 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_502.png' title='Pembayaran melalui CIMB Credit Card'></td>";
			echo "<td><select name='option_502'>";
			echo "<option value='502'>Full Payment</option>";
			if ($stat_502_3 =='yes'){
				echo "<option value='502_3'>Installment 3 Months</option>";
			}
			if ($stat_502_6 =='yes'){
				echo "<option value='502_6'>Installment 6 Months</option>";
			}
			if ($stat_502_12 =='yes'){
				echo "<option value='502_12'>Installment 12 Months</option>";
			}
			if ($stat_502_24 =='yes'){
				echo "<option value='502_24'>Installment 24 Months</option>";
			}
			echo "</td>";
        }
        if($stat_503 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=503 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_503.png' title='Pembayaran melalui Danamon Credit Card'></td>";
			echo "<td><select name='option_503'>";
			echo "<option value='503'>Full Payment</option>";
			if ($stat_503_3 =='yes'){
				echo "<option value='503_3'>Installment 3 Months</option>";
			}
			if ($stat_503_6 =='yes'){
				echo "<option value='503_6'>Installment 6 Months</option>";
			}
			if ($stat_503_12 =='yes'){
				echo "<option value='503_12'>Installment 12 Months</option>";
			}
			if ($stat_503_24 =='yes'){
				echo "<option value='503_24'>Installment 24 Months</option>";
			}
			echo "</td>";
        }
        if($stat_pro_1 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=pro1 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_pro1.png' title='Pembayaran melalui Credit Card Promotion 1'></td>";
			echo"<td></td>";
        }
		if($stat_pro_2 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=pro2 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_pro2.png' title='Pembayaran melalui Credit Card Promotion 2'></td>";
			echo"<td></td>";
        }
		if($stat_pro_3 == 'yes'){
            echo"<tr><td><input type=radio name=payment value=pro3 id=purDecFlag0 onclick=togglePurDec(event) />
            <img src='".get_home_url()."/wp-content/plugins/faspaycc/images/cc_pro3.png' title='Pembayaran melalui Credit Card Promotion 3'></td>";
			echo"<td></td>";
        }
        
        echo "</tr>";	

        echo "</table>";
        echo "<br>";

        echo '<div id=purchaseDecisionData style=display:none; margin-left:20px>';						
        echo "<ul class=customer_details><p></p>";

        $pattern = '/<!--:([#0-9A-Za-z]+)-->/';

        foreach($order->get_items() as $item) :
            echo '<strong>ITEM :&nbsp&nbsp'.$item['name'].'</strong> <br>'; 
        endforeach;
        echo '</div>';
		//SelectDataGeneralSettingInputAdminPanel->InMerchantDB		
        echo "<input type=hidden name=merchant_name value=$merchant_name>";
        echo "<input type=hidden name=server value=$server>";

        echo "<br>";
        echo "<input type=submit class=button name=submit id=submit value=Process>";
        echo "</form>";



		//ALLConditionStartHere
    if(isset($_POST['submit'])){
		
        WC()->cart->empty_cart();
		if($_POST['payment']=='500' || $_POST['payment']=='501' || $_POST['payment']=='502' || $_POST['payment']=='503'){
			$channel = $_POST['payment'];
			$option	= $_POST['option_'.$channel];
			$cre = get_conf_detail($option);
		}
		else {
			$cre = get_conf_detail($_POST['payment']);
		}
		//var_dump($option);exit;
			//FunctionParsingXML
        function  parse_xml2array( $input, $callback = NULL, $_recurse = FALSE ) {
        				// Get input, loading an xml string with simplexml if its the top level of recursion
            $data = ( ( !$_recurse ) && is_string( $input ) ) ? simplexml_load_string( $input ) : $input;		
        				// Convert SimpleXMLElements to array
            if ( $data instanceof SimpleXMLElement ) {
               $data = (array) $data;
           }		
        				// Recurse into arrays
           if ( is_array( $data ) ) foreach ( $data as &$item ) {
               $item = parse_xml2array( $item, $callback, TRUE );
           }		
        				// Run callback and return
           return ( !is_array( $data ) && is_callable( $callback ) ) ? call_user_func( $callback, $data ) : $data;
        }
    			//EndSendPostDataXML
		
    			//Function generate signature for request	
        function genSignaturereq($mid, $pass, $MerchanttranId, $amount, $tranId){

        	$signature = sha1(strtoupper('##'.$mid.'##'.$pass.'##'.$MerchanttranId.'##'.$amount.'##'.$tranId.'##'));

           return $signature; 
        }

			//EndFunctionGeneratorBCA

        $merchant_id 	= $cre['mid'];
        $merchant_name 	= $_POST['merchant_name'];
        $password 		= $cre['pass'];
		$pay_ind		= $cre['pymt_ind'];
		$pay_cri		= $cre['pymt_cri'];
        $server	 		= $_POST['server'];
		$url			= $server == "development" ? "https://ucdev.faspay.co.id/payment/PaymentWindow.jsp" : 
						  "https://uc.faspay.co.id/payment/PaymentWindow.jsp";
        $order_id 		= $order_id;
		$payment 		= $_POST['payment'];
		$installment	= substr($_POST['option_'.$payment],4,2);

        $price 			= $params['price'].'.00';
        $disc=$order->get_total_discount().'.00';
        foreach($order->get_items() as $item){
            $bill_gross += $item[line_subtotal]-$disc;
        }						
		$bill_gross = $bill_gross.'.00';
        $shipping		= $order->order_shipping.'.00';

        $email 			= $order->billing_email;

        $bill_date 		= $order->order_date;
        $bill_expired 	= '+'.$_POST['order_expired'].' '.'day';
        $expired_date 	= date('Y-m-d H:i:s',strtotime($bill_expired,strtotime($bill_date)));
        $productinfo 	= $item['name'];
        $qty 			= $item['qty'];
        $total 			= $item['line_subtotal'].'.00';
		
		$mi_signature 	= genSignaturereq($merchant_id,$password,$order_id,$total,0);	

        $cust_no 		= $order->customer_user;			
        $phone 			= preg_replace("/[^0-9.]/", '', $order->billing_phone);
        $address 		= $order->billing_address_1;
        $city 			= $order->billing_city;
        $postcode 		= $order->billing_postcode;
        $country_code 	= $order->billing_country;
        $state		 	= $order->billing_state;
        $custname 		= $order->billing_first_name." ".$order->billing_last_name;
		$srv			= get_bloginfo('wpurl');
		$return_url		= "$srv"."/wp-content/plugins/faspaycc/thanks-page.php";

        $post = array(
                  "LANG" 				=> '',                              
                  "MERCHANTID" 			=> $merchant_id,                                 	
                  "PAYMENT_METHOD"			=> '1',
                  "MERCHANT_TRANID"			=> $order_id,       
                  "CURRENCYCODE"			=> 'IDR',
                  "AMOUNT"				=> $total,
                  "CUSTNAME"				=> $custname,
                  "CUSTEMAIL"				=> $email,                                           
                  "DESCRIPTION"			=> $productinfo,
                  "RETURN_URL" 			=> $return_url,
                  "SIGNATURE" 			 	=> $mi_signature,                    
                  "BILLING_ADDRESS"			=> $address,
                  "BILLING_ADDRESS_CITY"	=> $city,
                  "BILLING_ADDRESS_REGION"		=> '',
                  "BILLING_ADDRESS_STATE"		=> $state,
                  "BILLING_ADDRESS_POSCODE"		=> $postcode,
                  "BILLING_ADDRESS_COUNTRY_CODE"		=> $country_code,
                  "RECEIVER_NAME_FOR_SHIPPING"		=> '',
                  "SHIPPING_ADDRESS" 			=> '',
                  "SHIPPING_ADDRESS_CITY" 		=> '',
                  "SHIPPING_ADDRESS_REGION"		=> '',
                  "SHIPPING_ADDRESS_STATE"		=> '',
                  "SHIPPING_ADDRESS_POSCODE"		=> '',
                  "SHIPPING_ADDRESS_COUNTRY_CODE"	=> '',
                  "SHIPPINGCOST"			=> '0.00',
                  "PHONE_NO" 				=> '',
                  "MREF1"				=> '',
                  "MREF2" 				=> '',
                  "MREF3"				=> '',
                  "MREF4"				=> '',
                  "MREF5"				=> '',
                  "MREF6"				=> '',
                  "MREF7"				=> '',
                  "MREF8"				=> '',
                  "MREF9"				=> '',
                  "MREF10"				=> '',
                  "MPARAM1" 				=> '',
                  "MPARAM2" 				=> '',
                  "CUSTOMER_REF"	 		=> '',
                  "PYMT_IND"				=> $pay_ind,
                  "PYMT_CRITERIA"			=> $pay_cri,
                  "FRISK1"				=> '',
                  "FRISK2"				=> '',
                  "DOMICILE_ADDRESS"			=> '',
                  "DOMICILE_ADDRESS_CITY"		=> '',
                  "DOMICILE_ADDRESS_REGION"		=> '',
                  "DOMICILE_ADDRESS_STATE"		=> '',
                  "DOMICILE_ADDRESS_POSCODE" 		=> '',
                  "DOMICILE_ADDRESS_COUNTRY_CODE"	=> '',
                  "DOMICILE_PHONE_NO"	 		=> '',
                  "handshake_url"			=> '',
                  "handshake_param"			=> '',
		);
        $string = '<form method="post" name="form" action='.$url.'>';
		if ($post != null) {
			foreach ($post as $name=>$value) {
				$string .= '<input type="hidden" name="'.$name.'" value="'.$value.'">';
			}
		}

		$string .= '</form>';
		$string .= '<script> document.form.submit();</script>';
		$insert_trx = $wpdb->query("insert into ". $wpdb->prefix ."faspaycc_order (order_id, date_trx, total_amount, payment, installment) values ('$order_id', '$bill_date', '$total', '$payment', '$installment')");
		update_paymentMethod($order_id,$payment,$installment);
		echo $string;
		}
    }

	/**
	 * Process the payment and return the result
	 **/
	function process_payment( $order_id ) {
        global $woocommerce;
        
        $order = new WC_Order( $order_id );
            
            /* 2.1.0 */
        $checkout_payment_url = $order->get_checkout_payment_url(true);

        return array(
            'result' => 'success', 
            'redirect' =>  
                add_query_arg(
                    'key', 
                    $order->order_key, 
                    $checkout_payment_url                       
            )
        );
    }

		/**
		 * receipt_page
		 **/
		function receipt_page( $order ) {
			global $woocommerce;
			//echo '<p>'.__('Thank you for your order.', 'woocommerce').'</p>';
			echo $this->generate_faspaycc_form( $order );
			
		}
		
		
	}

	/**
 	* Add the Gateway to WooCommerce
 	**/
     function add_faspaycc_gateway( $methods ) {
      $methods[] = 'WC_Gateway_faspaycc'; return $methods;
  }
  
  function get_conf_detail($option){
		global $wpdb;
	    $sql = "SELECT ". $wpdb->prefix ."options.option_value FROM ". $wpdb->prefix ."options WHERE ". $wpdb->prefix ."options.option_name = 'woocommerce_faspaycc_settings'";
        $active_plugins_data ="";
		$det =array();
        $paymentlist = $wpdb->get_results($sql, ARRAY_A);

        foreach ($paymentlist as $rows) {  
            $active_plugins_data .= $rows["option_value"];
        }

        $array = unserialize($active_plugins_data);
        $det['mid']				= $array["mid_".$option];
		$det['pass']			= $array["pass_".$option];
		$det['pymt_ind']		= $array["pymtind_".$option];
		$det['pymt_cri']		= $array["pymtcri_".$option];
		$det['server']			= $array["server"];		
		
		return $det;
  }
  
  function update_paymentMethod($orderId,$payment,$installment){
	  
	  require_once ('./wp-load.php');
	  require_once ('./wp-blog-header.php');
		
		if($payment != ''){
			if($payment  == 'all'){
				$payMethod = 'Visa/Master';
				$payMethodTitle = 'Visa / Master Credit Card';
			}
			elseif($payment  == '500'){
				$payMethod = 'Mandiri';
				$payMethodTitle = 'Mandiri Credit Card';
			}
			elseif($payment  == '501'){
				$payMethod = 'BCA';
				$payMethodTitle = 'BCA Credit Card';
			}
			elseif($payment  == '502'){
				$payMethod = 'CIMB';
				$payMethodTitle = 'CIMB Credit Card';
			}
			elseif($payment  == '503'){
				$payMethod = 'Danamon';
				$payMethodTitle = 'Danamon Credit Card';
			}
			elseif($payment  == 'pro_1'){
				$payMethod = 'Promo1';
				$payMethodTitle = 'Credit Card Promotion 1';
			}
			elseif($payment  == 'pro_2'){
				$payMethod = 'Promo2';
				$payMethodTitle = 'Credit Card Promotion 2';
			}
			elseif($payment  == 'pro_3'){
				$payMethod = 'Promo3';
				$payMethodTitle = 'Credit Card Promotion 3';
			}
			
			if($installment == '3'){
				$payMethod .= '3Bulan';
				$payMethodTitle .= ' Cicilan 3 Bulan';
			}
			elseif($installment == '6'){
				$payMethod .= '6Bulan';
				$payMethodTitle .= ' Cicilan 6 Bulan';
			}
			elseif($installment == '12'){
				$payMethod .= '12Bulan';
				$payMethodTitle .= ' Cicilan 12 Bulan';
			}
			elseif($installment == '24'){
				$payMethod .= '24Bulan';
				$payMethodTitle .= ' Cicilan 24 Bulan';
			}
			
			update_post_meta( $orderId, '_payment_method', $payMethod );

			update_post_meta( $orderId, '_payment_method_title', $payMethodTitle );
			
		}
		
  }

  add_filter('woocommerce_payment_gateways', 'add_faspaycc_gateway' );
}