<?php
/*
*Plugin Name: faspay Debit Channel - WooCommerce Gateway
*Plugin URI: https://www.faspay.co.id/
*Description: Plug-in to process payments in WooCommerce through faspay Payment Gateway.
*Version: 2.0
*Author: Periyanto, faspay
*Author URI: http://www.faspay.co.id/
*/
include_once( dirname( __FILE__ ) .'/faspay-install.php' );
register_activation_hook( __FILE__ , 'faspay_activation_process' );
register_deactivation_hook( __FILE__ , 'faspay_uninstallation_process' );

add_action('plugins_loaded', 'woocommerce_faspay_init', 0);
function woocommerce_faspay_init() {
	
	if ( !class_exists( 'WC_Payment_Gateway' ) ) return;
	/**
 	 * Localisation
	 */
	load_plugin_textdomain('wc-faspay', false, dirname( plugin_basename( __FILE__ ) ) . '/languages');
    
	/**
 	 * Gateway class
 	 */
	class WC_Gateway_Faspay extends WC_Payment_Gateway {
		
		public function __construct() {
			$this->id = 'faspay';
			$this->icon = null;
			$this->has_fields = false; 
			$this->init_form_fields();
			$this->init_settings();
			$this->method_title = 'faspay Debit Channel';
			$this->method_description ='faspay Payment Gateway Plug-in for WooCommerce';
			$this->title = $this->get_option( 'title' );
			$this->description = $this->get_option( 'description' );
			$this->user_id	= $this->get_option('user_id');
			$this->merchant_id	= $this->get_option('merchant_id');
			$this->password = $this->get_option('password');
			$this->klikPayCode = $this->get_option('klik_pay_code');
			$this->clearKey = $this->get_option('clear_key');
			$this->server = $this->get_option('server');

			if ( version_compare( WOOCOMMERCE_VERSION, '2.0.0', '>=' ) ) {
                add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( &$this, 'process_admin_options' ) );
            } else {
                add_action( 'woocommerce_update_options_payment_gateways', array( &$this, 'process_admin_options' ) );
            }
            add_action('woocommerce_receipt_faspay', array( $this, 'payment_page'));
           	add_action('woocommerce_api_wc_gateway_faspay', array( $this, 'response_faspay'));
           	
           
		}

		public function init_form_fields() {

			$this->form_fields = array(
						'enabled' => array(
							'title'		=> __( 'Enable / Disable', 'woothemes' ),
							'label'		=> __( 'Enable this payment gateway', 'woothemes' ),
							'type'		=> 'checkbox',
							'default'	=> 'no',
						),
						'title' => array(
							'title'		=> __( 'Title', 'woothemes' ),
							'type'		=> 'text',
							'desc_tip'	=> __( 'Payment title the customer will see during the checkout process.', 'woothemes' ),
							'default'	=> __( 'Online Payment via faspay', 'woothemes' ),
						),
						'description' => array(
							'title'		=> __( 'Description', 'woothemes' ),
							'type'		=> 'textarea',
							'desc_tip'	=> __( 'Payment description the customer will see during the checkout process.', 'woothemes' ),
							'default'	=> __( 'Pay Online securely via faspay channel.', 'woothemes' ),
							'css'		=> 'max-width:350px;'
						),
						'merchant_id' => array(
				            'title' => __( 'Merchant ID', 'woothemes' ), 
				            'type' => 'text', 
				            'description' => __( 'Please field merchant ID.', 'woothemes' ), 
			            ),
			        	'merchant_name' => array(
				            'title' => __( 'Merchant Name', 'woothemes' ), 
				            'type' => 'text', 
				            'description' => __( 'Please field merchant name.', 'woothemes' ), 
			            ),
			        	'user_id' => array(
				            'title' => __( 'User ID', 'woothemes' ), 
				            'type' => 'text', 
				            'description' => __( 'Please field user ID.', 'woothemes' ), 
			            ),
			        	'password' => array(
				            'title' => __( 'Password', 'woothemes' ), 
				            'type' => 'text', 
				            'description' => __( 'Please field password.', 'woothemes' ), 
			            ),
			        	'order_expire' => array(
				            'title' => __( 'Order Expire In', 'woothemes' ), 
				            'type' => 'text', 
				            'description' => __( 'Please field order expire. (In Hour)', 'woothemes' ), 
			            ),
			        	'server' => array(
				            'title' => __( 'Server', 'woothemes' ), 
				            'type' => 'select',
				            'options'  => array(
				               'DEVELOPMENT' => __( 'DEVELOPMENT', 'woothemes' ),
				               
				               'PRODUCTION'   => __( 'PRODUCTION', 'woothemes' )
				               ), 
				            'description' => __( 'Please field server.', 'woothemes' ) 
			            ),
			        	'tcash' => array(
				            'title' => __( 'Payment Channel', 'woothemes' ), 
				            'label' => __( 'T-Cash', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
			            ), 
			        	'xl_tunai' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'XL Tunai', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
			            ),
			        	'mynt_artajasa' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Mynt Artajasa', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
			            ),
			        	'mandiri_ecash' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Mandiri Ecash', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
			            ),
				        'dompetku' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Dompetku', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'bri_mobile_cash' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'BRI Mobile Cash', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'bri_epay' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'BRI E-Pay', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'permata_va' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Permata Virtual Account', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'permatanet' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'PermataNet', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),     	
				        'bca_klik_pay' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'BCA KlikPay', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'mandiri_click_pay' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Mandiri ClickPay', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'bii_mobile_banking' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'BII Mobile Banking', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'maybank_va' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Maybank Virtual Account', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'cimb_clicks' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'CIMB Clicks', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'danamon' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Danamon Debit Online', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'bca_va' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'BCA Virtual Account Online', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '',
				            'default' => 'no'
				        ),
				        'mandiri_billpayment' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Mandiri Bill Payment', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '',
				            'default' => 'no'
				        ),
				        'bca_sakuku' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'BCA Sakuku', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '',
				            'default' => 'no'
				        ),
				        'pp_indomaret' => array(
				            'title' => __( '', 'woothemes' ), 
				            'label' => __( 'Payment Point Indomaret', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '',
				            'default' => 'no'
				        ),
				        'parameter' => array(
				            'title' => __( 'BCA KlikPay Parameter :', 'woothemes' ), 
				            'type' => 'hidden',  
				        ),
				        'bca_mode' => array(
				           'title' => __( 'BCA KlikPay Mode', 'woothemes' ), 
				            'type' => 'select',
				            'options'  => array(
				               'DEVELOPMENT' => __( 'DEVELOPMENT', 'woothemes' ),

				               'UAT' => __( 'UAT', 'woothemes' ),

				               'PRODUCTION'   => __( 'PRODUCTION', 'woothemes' ),
				            ), 
				            'description' => __( 'Please field Mode.', 'woothemes' ), 
				        ),        
				        'klik_pay_code' => array(
				            'title' => __( 'Klik Pay Code', 'woothemes' ), 
				            'type' => 'text', 
				        ),
				        'clear_key' => array(
				            'title' => __( 'Clear Key', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'text_full_payment' => array(
				            'title' => __( '', 'woothemes' ), 
				            'type' => 'hidden', 
				            'description' => __( 'Konfigurasi Untuk Full Payment.', 'woothemes' ), 
				        ),
				        'mid_full_payment' => array(
				            'title' => __( 'MID Full Payment', 'woothemes' ), 
				            'type' => 'text',  
				        ),						
				        'cicilan_tiga_bulan' => array(
				            'title' => __( '', 'woothemes' ), 
				            'type' => 'hidden', 
				            'description' => __( 'Konfigurasi Untuk Cicilan 3 bulan.', 'woothemes' ), 
				        ),
				        'mid_tiga_bulan' => array(
				            'title' => __( 'MID Cicilan 3 Bulan', 'woothemes' ), 
				            'type' => 'text',  
				        ),
				        'pm_tiga_bulan' => array(
				            'title' => __( 'Price Minimum', 'woothemes' ), 
				            'type' => 'text',  
				        ),	
				        'status_cicilan_tiga' => array(
				            'title' => __( 'Status', 'woothemes' ), 
				            'label' => __( 'Enable', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),	
				        'cicilan_enam_bulan' => array(
				            'title' => __( '', 'woothemes' ), 
				            'type' => 'hidden', 
				            'description' => __( 'Konfigurasi Untuk Cicilan 6 bulan.', 'woothemes' ), 
				        ),
				        'mid_enam_bulan' => array(
				            'title' => __( 'MID Cicilan 6 Bulan', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'pm_enam_bulan' => array(
				            'title' => __( 'Price Minimum', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'status_cicilan_enam' => array(
				            'title' => __( 'Status', 'woothemes' ), 
				            'label' => __( 'Enable', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),			
				        'cicilan_duabelas_bulan' => array(
				            'title' => __( '', 'woothemes' ), 
				            'type' => 'hidden', 
				            'description' => __( 'Konfigurasi Untuk Cicilan 12 bulan.', 'woothemes' ), 
				        ),
				        'mid_duabelas_bulan' => array(
				            'title' => __( 'MID Cicilan 12 Bulan', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'pm_duabelas_bulan' => array(
				            'title' => __( 'Price Minimum', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'status_cicilan_duabelas' => array(
				            'title' => __( 'Status', 'woothemes' ), 
				            'label' => __( 'Enable', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'cicilan_duaempat_bulan' => array(
				            'title' => __( '', 'woothemes' ), 
				            'type' => 'hidden', 
				            'description' => __( 'Konfigurasi Untuk Cicilan 24 bulan.', 'woothemes' ), 
				        ),
				        'mid_duaempat_bulan' => array(
				            'title' => __( 'MID Cicilan 24 Bulan', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'pm_duaempat_bulan' => array(
				            'title' => __( 'Price Minimum', 'woothemes' ), 
				            'type' => 'text' 
				        ),
				        'status_cicilan_duaempat' => array(
				            'title' => __( 'Status', 'woothemes' ), 
				            'label' => __( 'Enable', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'title_mix' => array(
				            'title' => __( '', 'woothemes' ), 
				            'type' => 'hidden', 
				            'description' => __( 'Konfigurasi Untuk Kombinasi (MIX).', 'woothemes' ), 
				        ),
				        'status_mix' => array(
				            'title' => __( 'Status MIX', 'woothemes' ), 
				            'label' => __( 'Enable', 'woothemes' ), 
				            'type' => 'checkbox', 
				            'description' => '', 
				            'default' => 'no'
				        ),
				        'parameter_va' => array(
				            'title' => __( 'BCA VA Parameter :', 'woothemes' ), 
				            'type' => 'hidden',  
				        ),
				        'titile_parameter_va' => array(
				        	'title' => __('','woothemes'),
				        	'type' => 'hidden',
				        	'description' => __('Konfigurasi untuk Free Text BCA VA.','woothemes')
				        ),
				        'free_text1'=>array(
				        	'title' => __('Free Text Inquiry','woothemes'),
				        	'type' => 'text',
				        	'desc_tip'	=> __('Input Free Text sesuai dengan input di form BCA VA, pisahkan tiap free text dengan tanda |')
				        ),
				        'free_text2'=>array(
				        	'title' => __('Free Text Payment','woothemes'),
				        	'type' => 'text',
				        	'desc_tip'	=> __('Input Free Text sesuai dengan input di form BCA VA, pisahkan tiap free text dengan tanda |')
				        ),		
					);
		
		}

		/**
         * Admin Panel Options
         * - Options for bits like 'title' and availability on a country-by-country basis
         **/
        public function admin_options(){

            echo '<h3>'.__('faspay Payment Gateway', 'faspay').'</h3>';
            echo '<p>'.__('Allows Online payments via faspay').'</p>';
            echo '<table class="form-table">';
            $this->generate_settings_html();
            echo '</table>';

        }
    	

        /**
         *  There are no payment fields for faspay, but we want to show the description if set.
         **/
        function payment_fields() {

            if($this->description) echo wpautop(wptexturize($this->description));
        }

        function payment_page($order){


            echo '<p>'.__('Thank you for your order, please choose Payment Channel below to pay online via faspay.', 'faspay').'</p>';
            echo $this->generate_faspay_form($order);
        }

        function process_payment($order_id){
            global $woocommerce;
        
        	$order = new WC_Order( $order_id );
        	
            
            /* 2.1.0 */
        	$checkout_payment_url = $order->get_checkout_payment_url(true);

        	return array(
            	'result' => 'success', 
            	'redirect' =>  
                	add_query_arg(
                    	'key', 
                    	$order->order_key, 
                    	$checkout_payment_url                       
            		)
        	);
        }

        /* use for parsing xml */
        function  parse_xml2array( $input, $callback = NULL, $_recurse = FALSE ) {
        	
        	$data = ( ( !$_recurse ) && is_string( $input ) ) ? simplexml_load_string( $input ) : $input;		
        	
            	if ( $data instanceof SimpleXMLElement ) {
               		$data = (array) $data;
            	}		
        	
           		if ( is_array( $data ) ) foreach ( $data as &$item ) {
               		$item = $this->parse_xml2array( $item, $callback, TRUE );
           		}		
        
           	return ( !is_array( $data ) && is_callable( $callback ) ) ? call_user_func( $callback, $data ) : $data;
        }

        /* --- Use for generate key Id BCA ---*/
        function genKeyId($clearKey){
            return strtoupper(bin2hex($this->str2bin($clearKey)));
        }

        /* --- Use for generate signature BCA ---*/
        function genSignature($klikPayCode, $transactionDate, $transactionNo, $amount, $currency, $keyId){

        	//Signature Step 1
           $tempKey1 = $klikPayCode . $transactionNo . $currency . $keyId;
           $hashKey1 = $this->getHash($tempKey1);					 

        	// Signature Step 2
           $expDate = explode("/",substr($transactionDate,0,10));
           $strDate = $this->intval32bits($expDate[0] . $expDate[1] . $expDate[2]);
           $amt = $this->intval32bits($amount);
           $tempKey2 = $strDate + $amt;
           $hashKey2 = $this->getHash((string)$tempKey2);

        	// Generate Key Step 3
           $signature = abs($hashKey1 + $hashKey2);

           return $signature; 
        }

        function genAuthKey($klikPayCode, $transactionNo, $currency, $transactionDate, $keyId){

			//Step 1 - Padding
			$klikPayCode = str_pad($klikPayCode, 10, "0");
			$transactionNo = str_pad($transactionNo, 18, "A");
			$currency = str_pad($currency, 5, "1");
   
			//Step 2
			$value_1 = $klikPayCode . $transactionNo . $currency . $transactionDate . $keyId;
	
			//Step 3
			$hash_value_1 = strtoupper(md5($value_1));
	
			//Step 4
			if (strlen($keyId) == 32)
				$key = $keyId . substr($keyId,0,16);
			else if (strlen($keyId) == 48)
				$key = $keyId;
	
			// Hex encode the return value
			return strtoupper(bin2hex(mcrypt_encrypt(MCRYPT_3DES, hex2bin($key), hex2bin($hash_value_1), MCRYPT_MODE_ECB))); 
		}

        function convertHex2bin($data){
            $len = strlen($data);
            return pack("H" . $len, $data);
        }

        function str2bin($data){
            $len = strlen($data);
            return pack("a" . $len, $data);
        }

        function intval32bits($value){
             
            if ($value > 2147483647)
              $value = ($value - 4294967296);
            else if ($value < -2147483648)
              $value = ($value + 4294967296);

            return $value;
        }

        function getHash($value){
            
            $h = 0;
            for ($i = 0;$i < strlen($value);$i++){
              $h = $this->intval32bits($this->add31T($h) + ord($value{$i}));
            }
            return $h;
        }

        function add31T($value){
             
            $result = 0;
            for($i=1;$i <= 31;$i++){
              $result = $this->intval32bits($result + $value);
            }

            return $result;
        }

        /**Update Payment Channel Name**/
        function update_channel($orderId,$payment) {
          
		require_once ('./wp-load.php');
		require_once ('./wp-blog-header.php');
		            
		    if($payment != '') {
		                
		        if($payment  == '302') {
		            
		            $payMethod = 'T-cash';
		            $payMethodTitle = 'faspay - T-cash (302)';
		        }
		        elseif($payment  == '303'){
		            $payMethod = 'XL-Tunai';
		            $payMethodTitle = 'faspay - XL-Tunai (303)';
		        }
		        elseif($payment  == '304'){
		            $payMethod = 'Mynt';
		            $payMethodTitle = 'faspay - Mynt (304)';
		        }
		        elseif($payment  == '305'){
		            $payMethod = 'E-cash';
		            $payMethodTitle = 'faspay - E-cash (305)';
		        }
		        elseif($payment  == '307'){
		            $payMethod = 'Dompetku';
		            $payMethodTitle = 'faspay - Dompetku (307)';
		        }        
		        elseif($payment  == '400'){
		            $payMethod = 'Mocash';
		            $payMethodTitle = 'faspay - BRI-Mocash (400)';
		        }
		        elseif($payment  == '401'){
		            $payMethod = 'e-Pay';
		            $payMethodTitle = 'faspay - BRI-Epay(401)';
		        }
		        elseif($payment  == '402'){
		            $payMethod = 'VA Permata';
		            $payMethodTitle = 'faspay - VA Permata (402)';
		        }
		        elseif($payment  == 'permatanet'){
		            $payMethod = 'PermataNet';
		            $payMethodTitle = 'faspay - PermataNet (402)';
		        }
		        elseif($payment  == '405'){
		            $payMethod = 'BCA KlikPay';
		            $payMethodTitle = 'faspay - BCA KlikPay (405)';
		        }
		        elseif($payment  == '406'){
		            $payMethod = 'Mandiri Clikpay';
		            $payMethodTitle = 'faspay - Mandiri Clikpay (406)';
		        }                 
		        elseif($payment  == '407'){
		            $payMethod = 'Maybank Mobile Payment';
		            $payMethodTitle = 'faspay - Maybank Mobile Payment (407)';
		        }
		        elseif($payment  == '408'){
		            $payMethod = 'Maybank Virtual Account';
		            $payMethodTitle = 'faspay - Maybank Virtual Account (408)';
		        }
		        elseif($payment  == '700'){
		            $payMethod = 'CIMB Clicks';
		            $payMethodTitle = 'faspay - CIMB Clicks (700)';
		        }
		        elseif($payment  == '701'){
		            $payMethod = 'Danamon Online Banking';
		            $payMethodTitle = 'faspay - Danamon Online Banking (700)';
		        }
		        elseif($payment  == '702'){
		            $payMethod = 'BCA Virtual Account Online';
		            $payMethodTitle = 'faspay - BCA Virtual Account Online (700)';
		        }
		        elseif($payment  == '703'){
		            $payMethod = 'Mandiri Bill Payment';
		            $payMethodTitle = 'faspay - Mandiri Bill Payment (703)';
		        }
		        elseif($payment  == '704'){
		            $payMethod = 'BCA Sakuku';
		            $payMethodTitle = 'faspay - BCA Sakuku (704)';
		        }
		        elseif($payment  == '706'){
		            $payMethod = 'Payment Point Indomaret';
		            $payMethodTitle = 'faspay - Payment Point Indomaret (706)';
		        }

		        update_post_meta( $orderId, '_payment_method', $payMethod );

		        update_post_meta( $orderId, '_payment_method_title', $payMethodTitle );
		                
		    }
		            
		}


		/**
		 * @param $order_id
         */
		function generate_faspay_form($order_id ) {
        	global $woocommerce;
        	global $wpdb;
            
            $order = new WC_Order($order_id);
         
            echo "<form action='' method=post>";
            
            $sql = "SELECT ". $wpdb->prefix ."options.option_value FROM ". $wpdb->prefix ."options WHERE ". $wpdb->prefix ."options.option_name = 'woocommerce_faspay_settings'";
        	$active_plugins_data ="";

        	$paymentlist = $wpdb->get_results($sql, ARRAY_A);

        	foreach ($paymentlist as $rows) {  
            	$active_plugins_data .= $rows["option_value"];
        	}

        	$array = unserialize($active_plugins_data);
        
        	$merchant_id				= $array["merchant_id"];
	        $merchant_name				= $array["merchant_name"];
	        $user_id					= $array["user_id"];
	        $password					= $array["password"];
	        $order_expire				= $array["order_expire"];
	        $server						= $array["server"];
	        $tcash						= $array["tcash"];
	        $xl_tunai                   = $array["xl_tunai"];
	        $dompetku                   = $array["dompetku"];
	        $mynt_artajasa				= $array["mynt_artajasa"];
	        $mandiri_ecash              = $array["mandiri_ecash"];
	        $bri_mobile_cash			= $array["bri_mobile_cash"];
	        $bri_epay                   = $array["bri_epay"];
	        $permata_va					= $array["permata_va"];
	        $permatanet                 = $array["permatanet"];
	        $bca_klik_pay				= $array["bca_klik_pay"];
	        $mandiri_click_pay			= $array["mandiri_click_pay"];
	        $bii_mobile_banking		    = $array["bii_mobile_banking"];
	        $maybank_va		            = $array["maybank_va"];
	        $danamon                    = $array["danamon"];
	        $cimb_clicks                = $array["cimb_clicks"];
	        $bca_va	        			= $array["bca_va"];
	        $mandiri_billpayment        = $array["mandiri_billpayment"];
	        $bca_sakuku                 = $array["bca_sakuku"];
	        $pp_indomaret               = $array["pp_indomaret"];

	        $klik_pay_code              = $array["klik_pay_code"];
	        $clear_key                  = $array["clear_key"];
	        $bca_mode                   = $array["bca_mode"];
	        $mid_full_payment			= $array["mid_full_payment"];
	        $mid_tiga_bulan				= $array["mid_tiga_bulan"];
	        $pm_tiga_bulan				= $array["pm_tiga_bulan"];
	        $status_cicilan_tiga		= $array["status_cicilan_tiga"];
	        $mid_enam_bulan				= $array["mid_enam_bulan"];
	        $pm_enam_bulan				= $array["pm_enam_bulan"];
	        $status_cicilan_enam		= $array["status_cicilan_enam"];	
	        $mid_duabelas_bulan			= $array["mid_duabelas_bulan"];
	        $pm_duabelas_bulan			= $array["pm_duabelas_bulan"];
	        $status_cicilan_duabelas	= $array["status_cicilan_duabelas"];
	        $mid_duaempat_bulan			= $array["mid_duaempat_bulan"];
	        $pm_duaempat_bulan			= $array["pm_duaempat_bulan"];
	        $status_cicilan_duaempat	= $array["status_cicilan_duaempat"];
	        $status_mix					= $array["status_mix"];
	        $free_text1 				= $array["free_text1"];
	        $free_text2 				= $array["free_text2"];

	        echo "<table width=100%>";

		        if($tcash == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=302 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_302.png' title='Pembayaran melalui eMoney Telkomsel tCash'></td>";
		        }
		        if($xl_tunai == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=303 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_303.png' title='Pembayaran melalui eMoney XL Tunai'></td>";
		        }
		        if($mynt_artajasa == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=304 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_304.png' title='Pembayaran melalui eMoney MYNT Artajasa'></td>";
		        }
		        if($mandiri_ecash == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=305 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img alt='Mandiri Ecash' src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_305.png' title='Pembayaran melalui Mandiri E-cash'></td>";
		        }
		        if($dompetku == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=307 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img alt='Dompetku' src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_307.png' title='Pembayaran melalui eMoney XL Tunai'></td>";
		        }
		       
		        if($bri_mobile_cash == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=400 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_400.png' title='Pembayaran melalui Mobile Cash BRI'></td>";
		        }
		        if($bri_epay == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=401 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_401.png' title='Pembayaran melalui ePay BRI'></td>";
		        }
		       
		        if($mandiri_click_pay == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=406 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_406.png' title='Pembayaran melalui Mandiri clickPay'></td>";
		        }
		        if($bii_mobile_banking == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=407 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_407.png' title='Pembayaran melalui Mobile Banking BII'></td>";
		        }
		        	
		        if($maybank_va == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=408 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_408.png' title='Pembayaran melalui Virtual Account Maybank'></td>";
		        }
		        if($permata_va == 'yes'){
		            echo "<tr><td><input type=radio name=payment value=402 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_402.png' title='Pembayaran melalui Virtual Account Permata'></td>";
		        }
		         if($permatanet == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=permatanet id=purDecFlag0 onclick=togglePurDec(event) />
		            <img alt='bbmmoney' src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_permatanet.png' title='Pembayaran melalui PermataNet'></td>";
		        }
		        if($cimb_clicks == 'yes'){
		            echo "<tr><td><input type=radio name=payment value=700 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img alt='cimb clicks' src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_700.png' title='Pembayaran melalui CIMB Clicks'></td>";
		        }
		        if($danamon == 'yes'){
		            echo "<tr><td><input type=radio name=payment value=701 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img alt='danamon' src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_701.png' title='Pembayaran melalui Danamon Online Debit'></td>";
		        }
		        if($bca_va == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=702 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_702.png' title='Pembayaran melalui BCA Virtual Account Online'></td>";
		        }
		        if($mandiri_billpayment == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=703 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_703.png' title='Pembayaran melalui Mandiri Bill Payment'></td>";
		        }
		        if($pp_indomaret == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=706 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_706.png' title='Pembayaran melalui Payment Point Indomaret'></td>";
		        }if($bca_sakuku == 'yes'){
				echo"<tr><td><input type=radio name=payment value=704 id=purDecFlag0 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_704.png' title='Pembayaran melalui BCA Sakuku'></td>";
				}
		        if($bca_klik_pay == 'yes'){
		            echo"<tr><td><input type=radio name=payment value=405 id=purDecFlag1 onclick=togglePurDec(event) />
		            <img src='".get_home_url()."/wp-content/plugins/woocommerce-faspaydebit-gateway/assets/images/icon_faspay_405.png' title='Pembayaran melalui BCA KlikPay'></td>";
		        }   
		        echo "</tr>";	

		    echo "</table>";
		       
		        
		        //FunctionBCAklikPay
		        echo "<br>";
		        echo "<script>
		        function togglePurDec(evt) {
		          evt = (evt) ? evt : event;
		          var target = (evt.target) ? evt.target : evt.srcElement;
		          var block = document.getElementById('purchaseDecisionData');
		          if (target.id == 'purDecFlag1') {
		           block.style.display = 'block';
		           block.style.padding
		        } else {
		           block.style.display = 'none';
		        }
		        }
		        </script>";

		        echo '<div id=purchaseDecisionData style="display:none">';						
		       
		        echo '<table class="std">';
		        echo '<tr>';
		        echo '<th>Product Name</th>';
		        echo '<th>Product Price</th>';
		        echo '<th>Payment Type</th>';
		        echo '</tr>';
		        echo '<tbody>';
		        foreach($order->get_items() as $item) {
		          
		           echo '<tr>';
		           echo '<td>'.$item['name'].'</td>';
		           echo '<td>'.$item['line_total'].'</td>';
		           echo '<td>';
		           echo '<select name=payment_plan[]>';
		           echo '<option value="1">Full Payment</option>';
		              
		                if($status_cicilan_tiga == 'yes' && $item['line_total'] >= $pm_tiga_bulan){
		                    echo '<option value="2" >Cicilan 3 Bulan</option>';
		                }
		                if($status_cicilan_enam == 'yes' && $item['line_total'] >= $pm_enam_bulan){
		                    echo '<option value="3" >Cicilan 6 Bulan</option>';
		                }
		                if($status_cicilan_duabelas == 'yes' && $item['line_total'] >= $pm_duabelas_bulan){
		                    echo '<option value="4" >Cicilan 12 Bulan</option>';
		                }
		                if($status_cicilan_duaempat == 'yes' && $item['line_total'] >= $pm_duaempat_bulan){
		                    echo '<option value="5" >Cicilan 24 Bulan</option>';
		                }
		            
		            echo '</select>';
		            echo '</td>';
		            echo '</tr>'; 
		        }
		        echo '</table>';
		        echo '</div>';

		        echo '<style type="text/css">
		        table.std th, table.table_block th {
		        background: #999999 none repeat scroll 0 0;
		        color: #fff;
		        font-size: 12px;
		        font-weight: bold;
		        padding: 9px 1px;
		        text-shadow: 0 1px 0 black;
		        text-transform: uppercase;
		        vertical-align: top;
		        }
		        table.std td, table.table_block td {
		        border-bottom: 1px solid #e9e9e9;
		        border-right: 1px solid #e9e9e9;
		        font-size: 14px;
		        padding: 10px;
		        vertical-align: top;
		        }
		        </style>';

		    echo "<input type=hidden name=merchant_id value=$merchant_id>";
	        echo "<input type=hidden name=merchant_name value=$merchant_name>";
	        echo "<input type=hidden name=bca_mode value=$bca_mode>";
	        echo "<input type=hidden name=klik_pay_code value=$klik_pay_code>";
	        echo "<input type=hidden name=clear_key value=$clear_key>";
	        echo "<input type=hidden name=order_expired value=$order_expire>";
	        echo "<input type=hidden name=user_id value=$user_id>";
	        echo "<input type=hidden name=password value=$password>";
	        echo "<input type=hidden name=server value=$server>";

	        echo "<br>";
	        echo "<input type='submit' class='button alt' name='submit' id='submit' value='Process Payment'>";
	        echo "</form>";

	        if(isset($_POST['submit'])) {

	        	$merchant_id 			= $_POST['merchant_id'];
        		$merchant_name 			= $_POST['merchant_name'];
        		$user_id 				= $_POST['user_id'];
        		$password 				= $_POST['password'];
        		$order_id 				= $order_id;
        		$str 					= $user_id.$password.$order_id;
        		$mi_signature 			= hash('sha1',hash('md5',$str));
        		$bill_date 				= $order->order_date;
        		$order_expired 			= '+'.$_POST['order_expired'].' '.'hour';
        		$bill_expired 			= date('Y-m-d H:i:s',strtotime($order_expired,strtotime($bill_date)));
        		
        		$disc 			= $order->get_total_discount()*100.00;        		
        		$bill_gross		= $order->get_subtotal()*100.00 - $disc;
        		$bill_total		= $order->get_total()*100.00;
        		$shipping		= $order->order_shipping*100.00;

        		if($_POST['payment'] =='permatanet') {
            		$payment='402';
        		} else {
            		$payment 		= $_POST['payment'];
        		} 
        		
        		$first_name 			= $order->billing_first_name;
        		$last_name 				= $order->billing_last_name;
        		$email 					= $order->billing_email;
        		$phone 					= $order->billing_phone;
        		$cust_no 				= $order->customer_user;			
		        $phone 					= $order->billing_phone;
		        $billing_address 		= $order->billing_address_1;
		        $billing_city 			= $order->billing_city;
		        $billing_postcode 		= $order->billing_postcode;
		        $billing_country_code 	= $order->billing_country;
		        $billing_state		 	= $order->billing_state;
		        $custname 				= $order->shipping_first_name." ".$order->shipping_last_name;
		        $shipping_address 		= $order->shipping_address;
		        $shipping_city 			= $order->shipping_city;
		        $shipping_state 		= $order->shipping_state;
		        $shipping_postcode 		= $order->shipping_postcode;

        		
		        

		        //** prepare XML data to faspay
        		$xml = "<faspay>"."\n";
		        $xml.="<request>Post Data Transaksi</request>"."\n";
		        $xml.="<merchant_id>$merchant_id</merchant_id>"."\n";
		        $xml.="<merchant>$merchant_name</merchant>"."\n";
		        $xml.="<bill_no>$order_id</bill_no>"."\n";
		        $xml.="<bill_reff>$order_id</bill_reff>"."\n";
		        $xml.="<bill_date>$bill_date</bill_date>"."\n";
		        $xml.="<bill_expired>$bill_expired</bill_expired>"."\n";
		        $xml.="<bill_desc>Pembelian di $merchant_name</bill_desc>"."\n";
		        $xml.="<bill_currency>IDR</bill_currency>"."\n";
		        $xml.="<bill_gross>$bill_gross</bill_gross>"."\n";
		        $xml.="<bill_tax></bill_tax>"."\n";
		        $xml.="<bill_miscfee>$shipping</bill_miscfee>"."\n";
		        $xml.="<bill_total>$bill_total</bill_total>"."\n";
		        $xml.="<cust_no>$cust_no</cust_no>"."\n";
		        $xml.="<cust_name>$custname</cust_name>"."\n";
		        $xml.="<payment_channel>$payment</payment_channel>"."\n";

		        if($payment == '405') {
		        	
		        	$countpay = '0';
		        	$count= '';
            		foreach($_POST['payment_plan'] as $row=>$act) {
                 		$payplan = $_POST['payment_plan'][$row];

                		if($payplan){
                  			$countpay++;					 
                    		if($payplan >= '2' && $payplan != '1'){
                     			$count++;
                     			$pay = '2';
                    	
                    		}
                    	}
					}

					//**Installment condition
					if($count == $countpay){
						
						if($pay == '2'){
							$paytype = '2';
							$xml.="		<pay_type>2</pay_type>"."\n";

							$counter = 0;
							foreach($order->get_items() as $item){
								$name[$counter]=$item['name'];
								$qty[$counter]=$item['qty'];
								$nominal[$counter]=$item['line_total']*100.00*$qty[$counter];
								$counter++;
							}
							
							$counter = 0;
							foreach($_POST['payment_plan'] as $row=>$act){
								$payplan = $_POST['payment_plan'][$row];
								$xml.="		<item>"."\n";
								$xml.="			<product>$name[$counter]</product>"."\n";
								$xml.="			<qty>$qty[$counter]</qty>"."\n";
								$xml.="			<amount>$nominal[$counter]</amount>"."\n";
								$xml.="			<payment_plan>02</payment_plan>"."\n";
								
	                            	if($payplan == '2') {
	                               		$xml.="			<tenor>03</tenor>"."\n";
	                               		$xml.="			<merchant_id>$mid_tiga_bulan</merchant_id>"."\n";	
	                           		}elseif($payplan == '3'){
	                               		$xml.="			<tenor>06</tenor>"."\n";
	                               		$xml.="			<merchant_id>$mid_enam_bulan</merchant_id>"."\n";
	                           		}elseif($payplan == '4'){
	                               		$xml.="			<tenor>12</tenor>"."\n";
	                               		$xml.="			<merchant_id>$mid_duabelas_bulan</merchant_id>"."\n";
	                           		}else{
	                               		$xml.="			<tenor>24</tenor>"."\n";
	                               		$xml.="			<merchant_id>$mid_duaempat_bulan</merchant_id>"."\n";
	                           		}

	                           	$counter++;
	                           	$xml.="</item>"."\n";
	                       	}
	                       	if($counter > 5){
	                         	$url=$woocommerce->cart->get_checkout_url();
			     				echo "<script>alert('Sorry, only 5 item for installment transaction ! Please reduce your item first');</script>";
			     				echo "<script language='javascript'>window.location ='$url'</script>";
	                        }

	                    }
	                }
	                //**End Installment condition

	                //MIX condition	
		           	if 	($count < $countpay && $count != '') {
		               	$paytype = '3';
		               	if($status_mix == 'yes') {
		               		$xml.="		<pay_type>3</pay_type>"."\n";
		           		} else {
		           			echo "<script>alert('Sorry, this item not allow for combination transaction!');</script>";
		           			//echo "<script language='javascript'>window.location ='$woocommerce->cart->get_checkout_url()'</script>";
							//exit();
		           		}
		               $counter = 0;
		               foreach($order->get_items() as $item) {
		                   $name[$counter]=$item['name'];
		                   $qty[$counter]=$item['qty'];
		                   $nominal[$counter]=$item['line_total']*100.00 *$qty[$counter];
		                   $counter++;
		               }
		               	$counter = 0;
		               	$countertiga=0;
		               	$counterenam=0;
		               	$counterduabelas=0;
		               	$counterduaempat=0;
		               	foreach($_POST['payment_plan'] as $row=>$act) {
		                   	$payplan = $_POST['payment_plan'][$row];
		                   	$xml.="<item>"."\n";
		                   	$xml.="<product>$name[$counter]</product>"."\n";
		                   	$xml.="<qty>$qty[$counter]</qty>"."\n";
		                   	$xml.="<amount>$nominal[$counter]</amount>"."\n";

				                if($payplan == '1') {
				                    $xml.="<payment_plan>01</payment_plan>"."\n";
				                } else {
				                    $xml.="<payment_plan>02</payment_plan>"."\n";
				                }

				                if($payplan == '1') {
				                 	$xml.="<tenor>00</tenor>"."\n";
				                 	$xml.="<merchant_id>$mid_full_payment</merchant_id>"."\n";
				             	}elseif($payplan == '2') {
				                 	$xml.="<tenor>03</tenor>"."\n";
				                 	$xml.="<merchant_id>$mid_tiga_bulan</merchant_id>"."\n";
				                 	$countertiga++;	
				             	}elseif($payplan == '3') {
				                 	$xml.="<tenor>06</tenor>"."\n";
				                	$xml.="<merchant_id>$mid_enam_bulan</merchant_id>"."\n";
				                 	$counterenam++;
				             	}elseif($payplan == '4') {
				                 	$xml.="<tenor>12</tenor>"."\n";
				                 	$xml.="<merchant_id>$mid_duabelas_bulan</merchant_id>"."\n";
				                 	$counterduabelas++;
				             	}else{
				                 	$xml.="<tenor>24</tenor>"."\n";
				                 	$xml.="<merchant_id>$mid_duaempat_bulan</merchant_id>"."\n";
				                 	$counterduaempat++;
				             	}

		             		$counter++;
		             		$xml.="</item>"."\n";

						} 
						
						$counter_count = $countertiga+$counterenam+$counterduabelas+$counterduaempat;
						if($counter_count > 5){
							$url=$woocommerce->cart->get_checkout_url();
			     			echo "<script>alert('Sorry, only 5 item for installment transaction ! Please reduce your item first');</script>";
			     			echo "<script language='javascript'>window.location ='$url'</script>";
								  
						}

					}

					//NoInstallment
                    if($countpay = '2' && $count == '') {
                      $paytype = '1';
                      $xml.="<pay_type>1</pay_type>"."\n";
                      
                      	foreach($order->get_items() as $item) {	
                      		$nominal = $item['line_total']*100 *$item['qty'];
                      		$xml.="<item>"."\n";		
                      		$xml.="<product>".$item['name']."</product>"."\n";
                      		$xml.="<qty>".$item['qty']."</qty>"."\n";
                      		$xml.="<amount>".$nominal."</amount>"."\n";
                      		$xml.="<payment_plan>01</payment_plan>"."\n";
                      		$xml.="<tenor>00</tenor>"."\n";
                      		$xml.="<merchant_id>$mid_full_payment</merchant_id>"."\n";
                      		$xml.="</item>"."\n";
                      
                      	}	
					
                  	}
							
		        } else {
		        
		        $xml.="<pay_type>1</pay_type>"."\n";
		        $pattern = '/<!--:([#0-9A-Za-z]+)-->/';

		        	foreach($order->get_items() as $item) {

		        		$item_name= $item['name'];
		        		$item_qty = $item['qty'];
	                    $nominal = $item['line_total']*100.00*$item_qty;
	                    $xml.="<item>"."\n";		
	                    $xml.="<product>".preg_replace($pattern, '', $item_name)."</product>"."\n";
	                    $xml.="<qty>$item_qty</qty>"."\n";
	                    $xml.="<amount>$nominal</amount>"."\n";
	                    $xml.="<payment_plan>01</payment_plan>"."\n";
	                    $xml.="<tenor>00</tenor>"."\n";
	                    $xml.="<merchant_id></merchant_id>"."\n";
	                    $xml.="</item>"."\n";

		        	}
		        }
		        	
		        $xml.="		<msisdn>$phone</msisdn>"."\n";
		        $xml.="		<email>$email</email>"."\n";
		        $xml.="		<terminal>10</terminal>"."\n";
		        $xml.="		<billing_address>$billing_address</billing_address>"."\n";
		        $xml.="		<billing_address_city>$billing_city</billing_address_city>"."\n";
		        $xml.="		<billing_address_region></billing_address_region>"."\n";  
		        $xml.="		<billing_address_state>$billing_state</billing_address_state>"."\n";  
		        $xml.="		<billing_address_poscode>$billing_postcode</billing_address_poscode>"."\n";
		        $xml.="		<billing_address_country_code>$billing_country_code</billing_address_country_code>"."\n";  
		        $xml.="		<receiver_name_for_shipping>$custname</receiver_name_for_shipping>"."\n";  
		        $xml.="		<shipping_address>$shipping_address</shipping_address>"."\n";
		        $xml.="		<shipping_address_city>$shipping_city</shipping_address_city>"."\n";
		        $xml.="		<shipping_address_region></shipping_address_region>"."\n";
		        $xml.="		<shipping_address_state>$shipping_state</shipping_address_state>"."\n";
		        $xml.="		<shipping_address_poscode>$shipping_postcode</shipping_address_poscode>"."\n";
		        if ($payment=='702'){
		        	$xml.="		<reserve1>".$free_text2."</reserve1>"."\n";
		        	$xml.="		<reserve2>".$free_text1."</reserve2>"."\n";
		        } else {
		        	$xml.="		<reserve1></reserve1>"."\n";
		        	$xml.="		<reserve2></reserve2>"."\n";
		        }
		        
		        $xml.="		<signature>$mi_signature</signature>"."\n";								
		        $xml.="		</faspay>"."\n";

		        //print_r($xml);exit;

		        $url    = $_POST['server']=='PRODUCTION' ? "https://faspay.mediaindonusa.com/pws/300002/383xx00010100000" :
            	"http://faspaydev.mediaindonusa.com/pws/300002/183xx00010100000";

        		$body = $xml;
        		$c = curl_init ($url);
        		curl_setopt ($c, CURLOPT_POST, true);
        		curl_setopt ($c, CURLOPT_HTTPHEADER, array('Content-Type: text/xml'));
        		curl_setopt ($c, CURLOPT_POSTFIELDS, $body);
        		curl_setopt ($c, CURLOPT_RETURNTRANSFER, true);
        		curl_setopt ($c, CURLOPT_SSL_VERIFYPEER, false);
        		$page = curl_exec ($c);
        		curl_close ($c);
        		$rsp = $this->parse_xml2array($page);
        		
        		$this->update_channel($order_id,$_POST['payment']);
        		
        		$amount=$bill_gross/100.00;
        		$channel=get_post_meta( $order_id, '_payment_method', true );
        		
        		$insert_trx = $wpdb->query("insert into ". $wpdb->prefix ."faspay_order (trx_id, order_id, date_trx, total_amount,channel, status) values ('$rsp[trx_id]', '$order_id', '$bill_date', '$amount','$channel', 'pending')");
        		
        		 
        		//**ConditionUrlRedirect
			    if($payment == '405') {
			    	WC()->cart->empty_cart();
			        $clearKey			= $clear_key;
			        $klikPayCode		= $klik_pay_code;
			        $transactionNo		= $rsp['trx_id'];
			        $transactionDate	= date("d/m/Y H:i:s", strtotime($bill_date));
			        $totalAmount		= $bill_gross/100.00;
			        $currency			= "IDR";
			        $srv				= get_bloginfo('wpurl');
			      
			        $keyId = $this->genKeyId($clearKey);
			        $signature_bca = $this->genSignature($klikPayCode, $transactionDate, $transactionNo, $totalAmount, $currency, $keyId);

			        $post = array(

			               "klikPayCode"		=> $klikPayCode,
			               "transactionDate"	=> date("d/m/Y H:i:s", strtotime($bill_date)),
			               "transactionNo" 	    => $transactionNo,
			               "currency"			=> 'IDR',
			               "totalAmount" 		=> $totalAmount . '.00',
			               "payType"			=> '0'.$paytype,
			               "signature"			=> $signature_bca,
			               "descp"				=> 'Pembelian Barang di'.' '.$merchant_name,
			               "callback"			=> "$srv"."/?wc-api=WC_Gateway_Faspay&response_faspay/thankyou/&trx_id=$rsp[trx_id]",
			               "miscFee"			=> $shipping/100.00 . '.00'

			               );

			       
			        if($_POST['bca_mode']=='DEVELOPMENT') {
			                $urlBCA="http://faspaydev.mediaindonusa.com/redirectbca";
			        } else if($_POST['bca_mode']=='UAT') {
			                $urlBCA = "https://202.6.215.230:8081/purchasing/purchase.do?action=loginRequest";
			        } else {
			                $urlBCA = 'https://klikpay.klikbca.com/purchasing/purchase.do?action=loginRequest';
			        }

					  							
			        $string = '<form method="post" name="form" action="'.$urlBCA.'">';

			          	if ($post != null) {

			             	foreach ($post as $name => $value) {
			              		$string .= '<input type="hidden" name="'.$name.'" value="'.$value.'">';
			            	}
			        	}

			        $string .= '</form>';
			        $string .= '<script> document.form.submit();</script>';

			        echo $string;
			        exit; 
			    }
			    else if($_POST['payment']=='permatanet'){
			    	WC()->cart->empty_cart();
			        $rd = $_POST['server'] == 'DEVELOPMENT' ?
			        "http://faspaydev.mediaindonusa.com/permatanet/payment" :
			        "https://web.faspay.co.id/permatanet/payment";
			        
			        $post=array('va_number' => $rsp['trx_id'] , 
			                    'amount'   => $price/100
			                   );

			        $string = '<form method="post" name="form" action="'.$rd.'">';

			        if ($post != null) {

			            foreach ($post as $name => $value) {
			              	$string .= '<input type="hidden" name="'.$name.'" value="'.$value.'">';
			            }
			        }

			        $string .= '</form>';
			        $string .= '<script> document.form.submit();</script>';

			        echo $string;
			        exit; 

			    } else {

				//ConditionServer
			    	if($_POST['server'] =='DEVELOPMENT' ) {				
			    		$urlRedirect = "http://faspaydev.mediaindonusa.com/pws/100003/0830000010100000/";
			    	} else {
			        	$urlRedirect = "https://faspay.mediaindonusa.com/pws/100003/2830000010100000/";
			    	}	

			    WC()->cart->empty_cart();
			    
			    $url = $urlRedirect.$mi_signature.'?trx_id='.$rsp['trx_id'].'&merchant_id='.$merchant_id.'&bill_no='.$order_id;
			    ob_start();
			    header("Location:".$url);

				}
				
		    }

        }

        function get_orderid ($trx_id) {

        	global $wpdb;		 
		       	 
 
			$cekDB = $wpdb->get_results("select order_id from ". $wpdb->prefix ."faspay_order where trx_id = '$trx_id'",ARRAY_A);
			$order_id=$cekDB[0]['order_id'];
			
			return $order_id;
        }

        function inquiry_status ($trx_id,$order_id) {

        	$merchant_id = $this->merchant_id;
        	$password = $this->password;
        	$user_id = $this->user_id;
        	
        	$str 			= $user_id.$password.$order_id; 
	        $mi_signature 	= hash('sha1',hash('md5',$str));
	        $xml = "";
	        $xml .= 	"<faspay>";
	        $xml .= 	"<request>Inquiry Status Payment</request>";
	        $xml .= 	"<trx_id>$trx_id</trx_id>" . "\n";
	        $xml .= 	"<merchant_id>$merchant_id</merchant_id>";
	        $xml .= 	"<bill_no>$order_id</bill_no>";
	        $xml .= 	"<signature>$mi_signature</signature>";
	        $xml .= 	"</faspay>";
	        
	        $body = $xml;
							        
	        //ConditionServer 		      
	        $urldev		= "http://faspaydev.mediaindonusa.com/pws/100004/183xx00010100000";
	        $urlprod	= "https://faspay.mediaindonusa.com/pws/100004/383xx00010100000";
	        
	        if($this->server == 'DEVELOPMENT'){
	            $c = curl_init ($urldev);
	        }else{
	            $c = curl_init ($urlprod);
	        }
			
			curl_setopt ($c, CURLOPT_POST, true);
			curl_setopt ($c, CURLOPT_HTTPHEADER, array('Content-Type: text/xml'));
			curl_setopt ($c, CURLOPT_POSTFIELDS, $body);
			curl_setopt ($c, CURLOPT_RETURNTRANSFER, true);
			curl_setopt ($c, CURLOPT_SSL_VERIFYPEER, false);
			$response = curl_exec ($c);
			curl_close ($c);
			
			$xml = simplexml_load_string($response);
			$status = $xml->payment_status_code;

			return $status;	
        
		}

    	/**http://yourweb/?wc-api=WC_Gateway_Faspay&response_faspay**/
    	function response_faspay () {
        	
        global $woocommerce;
        global $wpdb;
		
		$path_url= $_SERVER['REQUEST_URI'];
		$path= explode('/',$path_url);      	
       	
       	switch (strtolower($path[3])) {
       		//** http://yourweb/?wc-api=WC_Gateway_Faspay&response_faspay/notify **//
       		case 'notify':
       			
       			$notif = $this->parse_xml2array(file_get_contents('php://input'));

       			$trx_id         = $notif['trx_id'];
    			$merchant_id    = $notif['merchant_id'];
    			$order_id       = $notif['bill_no'];
    			$payment_reff   = $notif['payment_reff'];
    			$payment_date   = $notif['payment_date'];
    			$payment_status = $notif['payment_status_code'];
    			$signature      = $notif['signature'];

    			$user_id 		= $this->user_id;
    			$password 		= $this->password;
    			$str 			= $user_id.$password.$order_id.$payment_status;
        		$sig 			= hash('sha1',hash('md5',$str));
        		//echo $sig;exit;
        		$response_date 	= date('Y-m-d H:i:s');
    			$order = new WC_Order($order_id);

    			$status 		= $order->status;

    			if ($signature==$sig) {

    				if ($status !='processing') {
    					
    					switch ($payment_status) {
	    					
	    					case '2':
	    						$order->payment_complete();
	    						$update_faspay = $wpdb->query("UPDATE ". $wpdb->prefix ."faspay_order SET status = 'payment sukses',date_payment='$payment_date', payment_reff = '$payment_reff' WHERE trx_id = '$trx_id'");

	    						//SendResponBerhasil->Faspay
								$xml ="<faspay>";
								$xml.="<response>Payment Notification</response>";
								$xml.="<trx_id>$trx_id</trx_id>";
								$xml.="<merchant_id>$merchant_id</merchant_id>";
								$xml.="<bill_no>$order_id</bill_no>";
								$xml.="<response_code>00</response_code>";
								$xml.="<response_desc>Sukses</response_desc>";
								$xml.="<response_date>$response_date</response_date>";
								$xml.="</faspay>";
						
								echo "$xml";

    						break;
    						
    						case '3':
    							echo "Transaction Failed";

    						break;

    					}

    				} else {
    					//SendResponBerhasil->Faspay
							$xml ="<faspay>";
							$xml.="<response>Payment Notification</response>";
							$xml.="<trx_id>$trx_id</trx_id>";
							$xml.="<merchant_id>$merchant_id</merchant_id>";
							$xml.="<bill_no>$order_id</bill_no>";
							$xml.="<response_code>14</response_code>";
							$xml.="<response_desc>Transaction Already Paid</response_desc>";
							$xml.="<response_date>$response_date</response_date>";
							$xml.="</faspay>";
						
							echo "$xml";
    					
    				}

    			} else {
    				echo "Failed Signature Validation";
    			}

    			
       			break;
       		//** http://yourweb/?wc-api=WC_Gateway_Faspay&response_faspay/check_signature_authkey/& **//
       		case 'check_signature_authkey':

       			isset($_GET['trx_id']) ?  $transactionNo = $_GET['trx_id'] : $trx_id_get = null;
				isset($_GET['signature']) ?  $signature_get = $_GET['signature'] : $signature_get =null;
				isset($_GET['authkey']) ?  $authkey_get = $_GET['authkey'] : $authkey_get = null;

				$order_id = $this->get_orderid ($transactionNo);
       			$order = new WC_Order($order_id);
       			$totalAmount = $order->get_subtotal();
       			$transactionDate = date("d/m/Y H:i:s", strtotime($order->order_date));
       			$klikPayCode = $this->klikPayCode;	
	        	$clearKey=$this->clearKey;
	        	$currency ='IDR';
	        	$keyId = $this->genKeyId($clearKey);
	        
	        	
	        	if($signature_get == ''){
															
					
					$authKey = $this->genAuthKey($klikPayCode,$transactionNo,$currency,$transactionDate,$keyId);
			
					if($authKey == $authkey_get){
						echo "1";
					} else {
						echo "0";
					}	
	
	
				} else {
	
					$signature_bca = $this->genSignature($klikPayCode, $transactionDate, $transactionNo, $totalAmount, $currency, $keyId);	
					
					if($signature_new == $signature_get){
						echo "1";
					} else {
						echo "0";
					}	
	

				}
	        	
       			break;

       		//** http://yourweb/?wc-api=WC_Gateway_Faspay&response_faspay/thankyou/& **//
       		case 'thankyou':
       		
       		$trx_id = $_GET['trx_id'];
       		
       		$order_id 	= $this->get_orderid ($trx_id);
       		$order 		= new WC_Order($order_id);
       		$custname 	= $order->shipping_first_name." ".$order->shipping_last_name;
       		$order_total= $order->get_total();
       		

       		$status= $this->inquiry_status($trx_id,$order_id);

       		if ($status=='2') {

       			$desc ="Thank You";
       			$status_desc="Your Payment is success";
       		} else {
       			$desc = "Transaction Failed";
       			$status_desc="Your Transaction is Failed";
       		}


       		$template = plugin_dir_path( __FILE__ ) . 'templates/';
       		wc_get_template('thanks-page.php', array('status'=>$status,'order_id'=>$order_id,'desc'=>$desc,'bill_total'=>$order_total,'customer'=>$custname,'payment_method'=>$order->payment_method,'status_desc'=>$status_desc), '', $template);
       		

       		break;
       	}
       	
       	exit;
    	
    	}
    
    }    
        
        	
	/**
 	* Add the Gateway to WooCommerce
 	**/
	function woocommerce_add_faspay_gateway($methods) {
		$methods[] = 'WC_Gateway_Faspay';
		return $methods;
	}
	
	add_filter('woocommerce_payment_gateways', 'woocommerce_add_faspay_gateway' );

} 